=======
History
=======

1.0.0 (2019-07-23)
------------------
* Dependicies fixed #16
* Valide gtf, fasta, vcf chrom annotation #15
* Ship mmsplice with prebuild exon set. #12
* Faster variant overlapping with pyranges #11
* Batch prediction with masking update in exon module

0.1.0 (2018-07-17)
------------------

* First release on PyPI.
